var componentPrefix = 'r';
function genBem(name, mods) {
  if (!mods) return '';
  if (typeof mods == 'string') return " ".concat(name, "--").concat(mods);
  if (Array.isArray(mods)) {
    return mods.reduce(function (ret, item) {
      return ret + genBem(name, item);
    }, '');
  }
  return Object.keys(mods).reduce(function (ret, key) {
    return ret + (mods[key] ? genBem(name, key) : '');
  }, '');
}

/**
 * CSS-BEM 命名规范: block-name__element-name--modifier-name，也就是模块名 + 元素名 + 修饰器名。
 *
 * bem helper
 * b() // 'button'
 * b('text') // 'button__text'
 * b({ disabled }) // 'button button--disabled'
 * b('text', { disabled }) // 'button__text button__text--disabled'
 * b(['disabled', 'primary']) // 'button button--disabled button--primary'
 */
function createBEM(name) {
  return function (el, mods) {
    if (el && typeof el !== 'string') {
      mods = el;
      el = '';
    }
    el = el ? "".concat(name, "__").concat(el) : name;
    return "".concat(el).concat(genBem(el, mods));
  };
}
function createNamespace(name) {
  var prefixName = "".concat(componentPrefix, "-").concat(name); // flex-fixed -> r-flex-fixed
  var prefixCls = "".concat(componentPrefix, "-").concat(name.toLowerCase().replace(/-(\w)/g, function (_, c) {
    return c;
  })); // flex-fixed -> r--flexfixed

  return {
    name: prefixName,
    class: prefixCls,
    bem: createBEM(prefixCls)
  };
}
export { createNamespace, componentPrefix };